# intellikit


[![image](https://img.shields.io/pypi/v/intellikit.svg)](https://pypi.python.org/pypi/intellikit)
[![image](https://img.shields.io/conda/vn/conda-forge/intellikit.svg)](https://anaconda.org/conda-forge/intellikit)


**A python toolkit for case based reasoning, information retrieval, natural language processing and other techniques for AI and intelligent systems.**

**“intellikit” i.e. Intelligent ToolKit** is a toolkit for **Case Based Reasoning** (CBR) and **Information Retrieval** (IR) in python. This package is being built primarily for educational purposes, and some content in it may be done more efficiently using Scikit-Learn and other libraries. In some instances such library functions are added directly in “intellikit” but feel free to test out those libraries concurrently and choose what suits your needs best. Some rare similarity measures are built from scratch but you can extend the functions or implement your own functions depending on your needs. 

In case you need help getting started, the website for this library can be [accessed here!](https://ArthurKakande.github.io/intellikit) Multiple demo projects are added to the examples tab.


-   Free software: MIT License
-   Documentation: https://ArthurKakande.github.io/intellikit
    

## Features

-   Case representations (Textual, Documents, Feature-value pairs, Object-oriented case representations, Graph case representations, etc.)
-   Similarity measures (Hamming distance, Hamming Similarity, Levenshtien distance, Levenshtien similarity, Level similarity, N-grams, Cosine similarity, Vector space model (TF - IDF), Okapi BM25, Sentence Transformers, City block metric, Euclidean distance, Weighted euclidean distance, etc)
